summaryrefslogtreecommitdiff
path: root/sfx2/source/doc
diff options
context:
space:
mode:
Diffstat (limited to 'sfx2/source/doc')
-rw-r--r--sfx2/source/doc/Metadatable.cxx2
-rw-r--r--sfx2/source/doc/docfile.cxx6
-rw-r--r--sfx2/source/doc/doctempl.cxx2
-rw-r--r--sfx2/source/doc/docvor.cxx2
-rw-r--r--sfx2/source/doc/graphhelp.cxx2
-rw-r--r--sfx2/source/doc/objcont.cxx2
-rw-r--r--sfx2/source/doc/objserv.cxx6
-rw-r--r--sfx2/source/doc/objstor.cxx18
-rw-r--r--sfx2/source/doc/objuno.cxx6
-rw-r--r--sfx2/source/doc/objxtor.cxx2
-rw-r--r--sfx2/source/doc/printhelper.cxx20
-rw-r--r--sfx2/source/doc/sfxbasemodel.cxx11
12 files changed, 40 insertions, 39 deletions
diff --git a/sfx2/source/doc/Metadatable.cxx b/sfx2/source/doc/Metadatable.cxx
index 9441d23d2f67..4e2c67b2269d 100644
--- a/sfx2/source/doc/Metadatable.cxx
+++ b/sfx2/source/doc/Metadatable.cxx
@@ -83,7 +83,7 @@
These serve only to track the position in an XML ID list in a document
registry, so that future actions can insert objects at the right position.
Unfortunately, inserting dummy objects seems to be necessary:
- <ul><li>it is not sufficent to just remember the saved id, because then
+ <ul><li>it is not sufficient to just remember the saved id, because then
the relative priorities might change when executing the undo</li>
<li>it is not sufficient to record the position as an integer, because
if we delete a text node and then undo, the node will be copied(!),
diff --git a/sfx2/source/doc/docfile.cxx b/sfx2/source/doc/docfile.cxx
index 2b44a05e6cae..708a484306fe 100644
--- a/sfx2/source/doc/docfile.cxx
+++ b/sfx2/source/doc/docfile.cxx
@@ -2533,7 +2533,7 @@ void SfxMedium::UseInteractionHandler( sal_Bool bUse )
::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >
SfxMedium::GetInteractionHandler()
{
- // if interaction isnt allowed explicitly ... return empty reference!
+ // if interaction isn't allowed explicitly ... return empty reference!
if ( !pImp->bUseInteractionHandler )
return ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >();
@@ -2546,7 +2546,7 @@ SfxMedium::GetInteractionHandler()
return xHandler;
}
- // if default interaction isnt allowed explicitly ... return empty reference!
+ // if default interaction isn't allowed explicitly ... return empty reference!
if ( !pImp->bAllowDefaultIntHdl )
return ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionHandler >();
@@ -3405,7 +3405,7 @@ sal_Bool SfxMedium::IsReadOnly()
{
sal_Bool bReadOnly = sal_False;
- // a) ReadOnly filter cant produce read/write contents!
+ // a) ReadOnly filter can't produce read/write contents!
bReadOnly = (
(pFilter ) &&
((pFilter->GetFilterFlags() & SFX_FILTER_OPENREADONLY) == SFX_FILTER_OPENREADONLY)
diff --git a/sfx2/source/doc/doctempl.cxx b/sfx2/source/doc/doctempl.cxx
index a76a3f978d7a..78c0bb85ee8f 100644
--- a/sfx2/source/doc/doctempl.cxx
+++ b/sfx2/source/doc/doctempl.cxx
@@ -134,7 +134,7 @@ class DocTempl_EntryData_Impl
{
RegionData_Impl* mpParent;
- // the following member must be SfxObjectShellLock since it controlls that SfxObjectShell lifetime by design
+ // the following member must be SfxObjectShellLock since it controls that SfxObjectShell lifetime by design
// and users of this class expect it to be so.
SfxObjectShellLock mxObjShell;
diff --git a/sfx2/source/doc/docvor.cxx b/sfx2/source/doc/docvor.cxx
index 15f9da8568f1..65e8de41481c 100644
--- a/sfx2/source/doc/docvor.cxx
+++ b/sfx2/source/doc/docvor.cxx
@@ -420,7 +420,7 @@ ImpPath_Impl::ImpPath_Impl( const ImpPath_Impl& rCopy ) :
Implementierungsklasse; Darstellung einer Position in der Outline-
Listbox als sal_uInt16-Array; dieses beschreibt die Position jeweil
- als relative Postion zum "ubergeordneten Eintrag
+ als relative Position zum "ubergeordneten Eintrag
*/
class Path
diff --git a/sfx2/source/doc/graphhelp.cxx b/sfx2/source/doc/graphhelp.cxx
index d8955f55e46c..792d122d71d1 100644
--- a/sfx2/source/doc/graphhelp.cxx
+++ b/sfx2/source/doc/graphhelp.cxx
@@ -356,7 +356,7 @@ sal_Bool GraphicHelper::createThumb_Impl( const GDIMetaFile& rMtf,
const_cast< GDIMetaFile& >( rMtf ).WindStart();
const_cast< GDIMetaFile& >( rMtf ).Play( &aVDev, aBackPosPix, aDrawSize );
- // draw overlay if neccessary
+ // draw overlay if necessary
if ( pOverlay )
aVDev.DrawBitmapEx( aOverlayRect.TopLeft(), aOverlayRect.GetSize(), *pOverlay );
diff --git a/sfx2/source/doc/objcont.cxx b/sfx2/source/doc/objcont.cxx
index 01e49b26c58e..052955447deb 100644
--- a/sfx2/source/doc/objcont.cxx
+++ b/sfx2/source/doc/objcont.cxx
@@ -247,7 +247,7 @@ void SfxObjectShell::UpdateTime_Impl(
util::Duration editDuration(sal_False, 0, 0, 0,
secs/3600, (secs%3600)/60, secs%60, 0);
- // Initialize some local member! Its neccessary for wollow operations!
+ // Initialize some local member! Its necessary for wollow operations!
DateTime aNow ; // Date and time at current moment
Time n24Time (24,0,0,0) ; // Time-value for 24 hours - see follow calculation
sal_uIntPtr nDays = 0 ; // Count of days between now and last editing
diff --git a/sfx2/source/doc/objserv.cxx b/sfx2/source/doc/objserv.cxx
index bdbcaec50132..6bf76f409c63 100644
--- a/sfx2/source/doc/objserv.cxx
+++ b/sfx2/source/doc/objserv.cxx
@@ -658,8 +658,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
GetMedium()->SetUpdatePickList( sal_True );
// TODO: in future it must be done in followind way
- // if document is opened from GUI it is immediatelly appeares in the picklist
- // if the document is a new one then it appeares in the picklist immediatelly
+ // if document is opened from GUI it is immediately appeares in the picklist
+ // if the document is a new one then it appeares in the picklist immediately
// after SaveAs operation triggered from GUI
}
catch( task::ErrorCodeIOException& aErrorEx )
@@ -1002,7 +1002,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
{
/*
- search for filter cant work correctly ...
+ search for filter can't work correctly ...
Because it's not clear, which export filter for which office module
must be searched. On the other side it can be very expensive doing so.
The best solution would be: on installation time we should know if pdf feature
diff --git a/sfx2/source/doc/objuno.cxx b/sfx2/source/doc/objuno.cxx
index dac80ffc1ec9..5e73366b37e7 100644
--- a/sfx2/source/doc/objuno.cxx
+++ b/sfx2/source/doc/objuno.cxx
@@ -692,7 +692,7 @@ void SAL_CALL SfxDocumentInfoObject::removeProperty(const ::rtl::OUString& sName
::rtl::OUStringBuffer sMsg(256);
sMsg.appendAscii("The property \"" );
sMsg.append (sName );
- sMsg.appendAscii("\" cant be removed. Its a fix property of the DocumentInfo service.");
+ sMsg.appendAscii("\" can't be removed. Its a fix property of the DocumentInfo service.");
throw ::com::sun::star::beans::NotRemoveableException(
sMsg.makeStringAndClear(),
@@ -721,7 +721,7 @@ void SAL_CALL SfxDocumentInfoObject::setFastPropertyValue(sal_Int32 nHandle, co
lang::WrappedTargetException)
{
// Attention: Only fix properties should be provided by this method.
- // Dynamic properties has no handle in real ... because it cant be used inside multithreaded environments :-)
+ // Dynamic properties has no handle in real ... because it can't be used inside multithreaded environments :-)
::osl::ClearableMutexGuard aGuard( _pImp->_aMutex );
@@ -937,7 +937,7 @@ void SAL_CALL SfxDocumentInfoObject::setFastPropertyValue(sal_Int32 nHandle, co
lang::WrappedTargetException)
{
// Attention: Only fix properties should be provided by this method.
- // Dynamic properties has no handle in real ... because it cant be used inside multithreaded environments :-)
+ // Dynamic properties has no handle in real ... because it can't be used inside multithreaded environments :-)
::osl::MutexGuard aGuard( _pImp->_aMutex );
::com::sun::star::uno::Any aValue;
diff --git a/sfx2/source/doc/objxtor.cxx b/sfx2/source/doc/objxtor.cxx
index 01141e9bb42f..5591e1d224ac 100644
--- a/sfx2/source/doc/objxtor.cxx
+++ b/sfx2/source/doc/objxtor.cxx
@@ -494,7 +494,7 @@ SfxObjectShell* SfxObjectShell::GetFirst
{
SfxObjectShellArr_Impl &rDocs = SFX_APP()->GetObjectShells_Impl();
- // seach for a SfxDocument of the specified type
+ // search for a SfxDocument of the specified type
for ( sal_uInt16 nPos = 0; nPos < rDocs.Count(); ++nPos )
{
SfxObjectShell* pSh = rDocs.GetObject( nPos );
diff --git a/sfx2/source/doc/sfxbasemodel.cxx b/sfx2/source/doc/sfxbasemodel.cxx
index 79d648980604..1c6793297a65 100644
--- a/sfx2/source/doc/sfxbasemodel.cxx
+++ b/sfx2/source/doc/sfxbasemodel.cxx
@@ -510,7 +510,7 @@ SfxSaveGuard::~SfxSaveGuard()
// storing at the same time. Further m_bSuicide was set to sal_True only if close(sal_True) was called.
// So the owner ship was delegated to the place where a veto exception was thrown.
// Now we have to call close() again and delegate the owner ship to the next one, which
- // cant accept that. Close(sal_False) cant work in this case. Because then the document will may be never closed ...
+ // can't accept that. Close(sal_False) can't work in this case. Because then the document will may be never closed ...
if ( m_pData->m_bSuicide )
{
@@ -1431,7 +1431,7 @@ void SAL_CALL SfxBaseModel::removeModifyListener(const uno::Reference< XMODIFYLI
void SAL_CALL SfxBaseModel::close( sal_Bool bDeliverOwnership ) throw (util::CloseVetoException, uno::RuntimeException)
{
- static ::rtl::OUString MSG_1 = ::rtl::OUString::createFromAscii("Cant close while saving.");
+ static ::rtl::OUString MSG_1 = ::rtl::OUString::createFromAscii("Can't close while saving.");
::vos::OGuard aGuard( Application::GetSolarMutex() );
if ( impl_isDisposed() || m_pData->m_bClosed || m_pData->m_bClosing )
@@ -1610,7 +1610,8 @@ void SAL_CALL SfxBaseModel::storeSelf( const uno::Sequence< beans::PropertyVa
if ( !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "VersionComment" ) ) )
&& !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Author" ) ) )
&& !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "InteractionHandler" ) ) )
- && !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StatusIndicator" ) ) ) )
+ && !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StatusIndicator" ) ) )
+ && !aSeqArgs[nInd].Name.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FailOnWarning" ) ) ) )
{
m_pData->m_pObjectShell->AddLog( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "unexpected parameter for storeSelf, might be no problem if SaveAs is executed." ) ) );
m_pData->m_pObjectShell->StoreLog();
@@ -2489,7 +2490,7 @@ void SAL_CALL SfxBaseModel::removeDocumentEventListener( const uno::Reference< d
void SAL_CALL SfxBaseModel::notifyDocumentEvent( const ::rtl::OUString&, const uno::Reference< frame::XController2 >&, const uno::Any& )
throw ( lang::IllegalArgumentException, lang::NoSupportException, uno::RuntimeException )
{
- throw lang::NoSupportException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SfxBaseModel controlls all the sent notifications itself!" ) ), uno::Reference< uno::XInterface >() );
+ throw lang::NoSupportException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "SfxBaseModel controls all the sent notifications itself!" ) ), uno::Reference< uno::XInterface >() );
}
//________________________________________________________________________________________________________
@@ -2833,7 +2834,7 @@ void SfxBaseModel::impl_store( const ::rtl::OUString& sURL
else
{
// if the password is changed a special error should be used in case of shared document
- throw task::ErrorCodeIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Cant change password for shared document." ) ), uno::Reference< uno::XInterface >(), ERRCODE_SFX_SHARED_NOPASSWORDCHANGE );
+ throw task::ErrorCodeIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Can't change password for shared document." ) ), uno::Reference< uno::XInterface >(), ERRCODE_SFX_SHARED_NOPASSWORDCHANGE );
}
}
}
diff --git a/sfx2/source/doc/objstor.cxx b/sfx2/source/doc/objstor.cxx
index 2c9fe1e34fe4..e130de7cf051 100644
--- a/sfx2/source/doc/objstor.cxx
+++ b/sfx2/source/doc/objstor.cxx
@@ -299,10 +299,10 @@ sal_Bool SfxObjectShell::PutURLContentsToVersionStream_Impl(
uno::Reference< embed::XStorage > xTempStorage =
::comphelper::OStorageHelper::GetStorageFromURL( aTempURL, embed::ElementModes::READWRITE );
- // the password will be transfered from the xStorage to xTempStorage by storage implemetation
+ // the password will be transferred from the xStorage to xTempStorage by storage implemetation
xStorage->copyToStorage( xTempStorage );
// the temporary storage was commited by the previous method and it will die by refcount
}
catch ( uno::Exception& )
{
@@ -1253,9 +1253,9 @@ sal_Bool SfxObjectShell::SaveTo_Impl
// The active storage must be switched. The simple saving is not enough.
// The problem is that the target medium contains target MediaDescriptor.
- // In future the switch of the persistance could be done on stream level:
+ // In future the switch of the persistence could be done on stream level:
// a new wrapper service will be implemented that allows to exchange
- // persistance on the fly. So the real persistance will be set
+ // persistence on the fly. So the real persistence will be set
// to that stream only after successful commit of the storage.
// TODO/LATER:
// create wrapper stream based on the URL
@@ -1264,7 +1264,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
// commit the new storage
// call saveCompleted based with this new storage ( get rid of old storage and "frees" URL )
// commit the wrapper stream ( the stream will connect the URL only on commit, after that it will hold it )
- // if the last step is failed the stream should stay to be transacted and should be commited on any flush
+ // if the last step is failed the stream should stay to be transacted and should be committed on any flush
// so we can forget the stream in any way and the next storage commit will flush it
AddLog( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Save: Own to Own" ) ) );
@@ -1629,7 +1629,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
{
pMedium->Close();
// target medium is still not commited, it should not be closed
// commit the package storage and close it, but leave the streams open
rMedium.StorageCommit_Impl();
rMedium.CloseStorage();
@@ -2014,7 +2014,7 @@ sal_Bool SfxObjectShell::DoSaveObjectAs( SfxMedium& rMedium, sal_Bool bCommit )
}
catch( uno::Exception& )
{
- DBG_ERROR( "The strotage was not commited on DoSaveAs!\n" );
+ DBG_ERROR( "The strotage was not committed on DoSaveAs!\n" );
}
}
}
@@ -2938,7 +2938,7 @@ sal_Bool SfxObjectShell::PreDoSaveAs_Impl
DBG_ERROR("Salvage item present in Itemset, check the parameters!");
#endif
- // should be unneccessary - too hot to handle!
+ // should be unnecessary - too hot to handle!
pMergedParams->ClearItem( SID_DOC_SALVAGE );
// take over the new merged itemset
@@ -3526,7 +3526,7 @@ sal_Bool StoragesOfUnknownMediaTypeAreCopied_Impl( const uno::Reference< embed::
}
catch( uno::Exception& )
{
- OSL_ENSURE( sal_False, "Cant check storage consistency!\n" );
+ OSL_ENSURE( sal_False, "Can't check storage consistency!\n" );
}
return sal_True;
@@ -299,10 +299,10 @@ sal_Bool SfxObjectShell::PutURLContentsToVersionStream_Impl(
xStorage->copyToStorage( xTempStorage );
- // the temporary storage was commited by the previous method and it will die by refcount
+ // the temporary storage was committed by the previous method and it will die by refcount
}
catch ( uno::Exception& )
@@ -1629,7 +1629,7 @@ sal_Bool SfxObjectShell::SaveTo_Impl
{
pMedium->Close();
- // target medium is still not commited, it should not be closed
+ // target medium is still not committed, it should not be closed
// commit the package storage and close it, but leave the streams open
rMedium.StorageCommit_Impl();
diff --git a/sfx2/source/doc/printhelper.cxx b/sfx2/source/doc/printhelper.cxx
index 85e1d7b26f47..b3d02ef689b6 100644
--- a/sfx2/source/doc/printhelper.cxx
+++ b/sfx2/source/doc/printhelper.cxx
@@ -484,7 +484,7 @@ class ImplUCBPrintWatcher : public ::osl::Thread
SfxPrinter* m_pPrinter;
/// this describes the target location for the printed temp file
String m_sTargetURL;
- /// it holds the temp file alive, till the print job will finish and remove it from disk automaticly if the object die
+ /// it holds the temp file alive, till the print job will finish and remove it from disk automatically if the object die
::utl::TempFile* m_pTempFile;
public:
@@ -510,11 +510,11 @@ class ImplUCBPrintWatcher : public ::osl::Thread
}
/* } SAFE */
// lock for further using of our member isn't neccessary - because
// we truns alone by defenition. Nobody join for us nor use us ...
ImplUCBPrintWatcher::moveAndDeleteTemp(&m_pTempFile,m_sTargetURL);
- // finishing of this run() method will call onTerminate() automaticly
+ // finishing of this run() method will call onTerminate() automatically
// kill this thread there!
}
@@ -526,7 +526,7 @@ class ImplUCBPrintWatcher : public ::osl::Thread
}
/* static helper to move the temp. file to the target location by using the ucb
- It's static to be useable from outside too. So it's not realy neccessary to start
+ It's static to be useable from outside too. So it's not really necessary to start
the thread, if finishing of the job was detected outside this thread.
But it must be called without using a corresponding thread for the given parameter!
*/
@@ -598,7 +598,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// by executing the slot. Because if it is a ucb relevant URL we must wait for
// finishing the print job and move the temporary local file by using the ucb
// to the right location. But in case of no file name is given or it is already
- // a local one we can supress this special handling. Because then vcl makes all
+ // a local one we can suppress this special handling. Because then vcl makes all
// right for us.
String sUcbUrl;
::utl::TempFile* pUCBPrintTempFile = NULL;
@@ -635,7 +635,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// reasons. Otherwhise we break to much external code ...
// We try to convert it to a file URL. If its possible
// we put the system path to the item set and let vcl work with it.
// No ucb or thread will be neccessary then. In case it couldnt be
// converted its not an URL nor a system path. Then we can't accept
// this parameter and have to throw an exception.
::rtl::OUString sSystemPath(sTemp);
@@ -670,7 +670,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// it's an ucb target. So we must use a temp. file for vcl
// and move it after printing by using the ucb.
// Create a temp file on the heap (because it must delete the
- // real file on disk automaticly if it die - bt we have to share it with
+ // real file on disk automatically if it die - bt we have to share it with
// some other sources ... e.g. the ImplUCBPrintWatcher).
// And we put the name of this temp file to the descriptor instead
// of the URL. The URL we save for later using seperatly.
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// Ok - may be execution before has finished (or started!) printing.
// And may it was a printing to a file.
// Now we have to check if we can move the file (if neccessary) via ucb to his right location.
// Cases:
// a) printing finished => move the file directly and forget the watcher thread
// b) printing is asynchron and runs currently => start watcher thread and exit this method
// This thread make all neccessary things by itself.
if (pUCBPrintTempFile!=NULL)
{
// a)
@@ -778,7 +778,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
else
{
// Note: we create(d) some ressource on the heap. (thread and tep file)
- // They will be delected by the thread automaticly if he finish his run() method.
+ // They will be delected by the thread automatically if he finish his run() method.
ImplUCBPrintWatcher* pWatcher = new ImplUCBPrintWatcher( pPrinter, pUCBPrintTempFile, sUcbUrl );
pWatcher->create();
}
@@ -510,11 +510,11 @@ class ImplUCBPrintWatcher : public ::osl::Thread
}
/* } SAFE */
- // lock for further using of our member isn't neccessary - because
+ // lock for further using of our member isn't necessary - because
// we truns alone by defenition. Nobody join for us nor use us ...
ImplUCBPrintWatcher::moveAndDeleteTemp(&m_pTempFile,m_sTargetURL);
@@ -635,7 +635,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// We try to convert it to a file URL. If its possible
// we put the system path to the item set and let vcl work with it.
- // No ucb or thread will be neccessary then. In case it couldnt be
+ // No ucb or thread will be necessary then. In case it couldn't be
// converted its not an URL nor a system path. Then we can't accept
// this parameter and have to throw an exception.
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// Ok - may be execution before has finished (or started!) printing.
// And may it was a printing to a file.
- // Now we have to check if we can move the file (if neccessary) via ucb to his right location.
+ // Now we have to check if we can move the file (if necessary) via ucb to his right location.
// Cases:
// a) printing finished => move the file directly and forget the watcher thread
@@ -763,11 +763,11 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
// a) printing finished => move the file directly and forget the watcher thread
// b) printing is asynchron and runs currently => start watcher thread and exit this method
- // This thread make all neccessary things by itself.
+ // This thread make all necessary things by itself.
if (pUCBPrintTempFile!=NULL)
{